identity.py — Rucio 1.12.2 documentation

# identity.py

`PUT` `/identities/<account>/x509`

  > Create a new identity and map it to an account.

  Example request:

      PUT /identities/<account>/x509 HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

`PUT` `/identities/<account>/gss`

  > Create a new identity and map it to an account.

  Example request:

      PUT /identities/<account>/gss HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: